@@ -8,16 +8,15 @@ import (
 	"github.com/wagoodman/go-partybus"
 	"github.com/wagoodman/go-progress"
 
-	grypeDb "github.com/anchore/grype/grype/db/v5"
+	v5 "github.com/anchore/grype/grype/db/v5"
+	"github.com/anchore/grype/grype/db/v5/matcher"
+	"github.com/anchore/grype/grype/db/v5/matcher/stock"
 	"github.com/anchore/grype/grype/distro"
 	"github.com/anchore/grype/grype/event"
 	"github.com/anchore/grype/grype/event/monitor"
 	"github.com/anchore/grype/grype/grypeerr"
 	"github.com/anchore/grype/grype/match"
-	"github.com/anchore/grype/grype/matcher"
-	"github.com/anchore/grype/grype/matcher/stock"
 	"github.com/anchore/grype/grype/pkg"
-	"github.com/anchore/grype/grype/store"
 	"github.com/anchore/grype/grype/vex"
 	"github.com/anchore/grype/grype/vulnerability"
 	"github.com/anchore/grype/internal/bus"
@@ -32,7 +31,7 @@ const (
 )
 
 type VulnerabilityMatcher struct {
-	Store          store.Store
+	Store          v5.ProviderStore
 	Matchers       []matcher.Matcher
 	IgnoreRules    []match.IgnoreRule
 	FailSeverity   *vulnerability.Severity
@@ -40,7 +39,7 @@ type VulnerabilityMatcher struct {
 	VexProcessor   *vex.Processor
 }
 
-func DefaultVulnerabilityMatcher(store store.Store) *VulnerabilityMatcher {
+func DefaultVulnerabilityMatcher(store v5.ProviderStore) *VulnerabilityMatcher {
 	return &VulnerabilityMatcher{
 		Store:    store,
 		Matchers: matcher.NewDefaultMatchers(matcher.Config{}),
@@ -66,6 +65,7 @@ func (m *VulnerabilityMatcher) FindMatches(pkgs []pkg.Package, context pkg.Conte
 	progressMonitor := trackMatcher(len(pkgs))
 
 	defer func() {
+		progressMonitor.Ignored.Set(int64(len(ignoredMatches)))
 		progressMonitor.SetCompleted()
 		if err != nil {
 			progressMonitor.MatchesDiscovered.SetError(err)
@@ -83,6 +83,11 @@ func (m *VulnerabilityMatcher) FindMatches(pkgs []pkg.Package, context pkg.Conte
 		return remainingMatches, ignoredMatches, err
 	}
 
+	if m.FailSeverity != nil && HasSeverityAtOrAbove(m.Store, *m.FailSeverity, *remainingMatches) {
+		err = grypeerr.ErrAboveSeverityThreshold
+		return remainingMatches, ignoredMatches, err
+	}
+
 	logListSummary(progressMonitor)
 
 	logIgnoredMatches(ignoredMatches)
@@ -111,14 +116,25 @@ func (m *VulnerabilityMatcher) findDBMatches(pkgs []pkg.Package, context pkg.Con
 		// regresses the results (relative to the already applied ignore rules). Why do we additionally apply
 		// the ignore rules before normalizing? In case the user has a rule that ignores a non-normalized
 		// vulnerability ID, we wantMatches to ensure that the rule is honored.
+		originalIgnoredMatches := ignoredMatches
 		matches, ignoredMatches = m.applyIgnoreRules(normalizedMatches)
+		ignoredMatches = m.mergeIgnoredMatches(originalIgnoredMatches, ignoredMatches)
 	}
 
-	if m.FailSeverity != nil && HasSeverityAtOrAbove(m.Store, *m.FailSeverity, matches) {
-		err = grypeerr.ErrAboveSeverityThreshold
-	}
+	return &matches, ignoredMatches, nil
+}
 
-	return &matches, ignoredMatches, err
+func (m *VulnerabilityMatcher) mergeIgnoredMatches(allIgnoredMatches ...[]match.IgnoredMatch) []match.IgnoredMatch {
+	var out []match.IgnoredMatch
+	for _, ignoredMatches := range allIgnoredMatches {
+		for _, ignored := range ignoredMatches {
+			if m.NormalizeByCVE {
+				ignored.Match = m.normalizeByCVE(ignored.Match)
+			}
+			out = append(out, ignored)
+		}
+	}
+	return out
 }
 
 func (m *VulnerabilityMatcher) searchDBForMatches(
@@ -193,7 +209,7 @@ func (m *VulnerabilityMatcher) searchDBForMatches(
 func indexFalsePositivesByLocation(
 	d *distro.Distro,
 	packages []pkg.Package,
-	s store.Store,
+	s v5.ProviderStore,
 ) (map[string][]string, error) {
 	distroFalsePositivesByLocationPath := make(map[string][]string)
 
@@ -210,7 +226,7 @@ func indexFalsePositivesByLocation(
 	return distroFalsePositivesByLocationPath, nil
 }
 
-func getDistroFalsePositivesByLocation(s store.Store, d *distro.Distro, p pkg.Package) (map[string][]string, error) {
+func getDistroFalsePositivesByLocation(s v5.ProviderStore, d *distro.Distro, p pkg.Package) (map[string][]string, error) {
 	result := make(map[string][]string)
 
 	if data, ok := p.Metadata.(pkg.ApkMetadata); ok {
@@ -416,7 +432,7 @@ func isCVE(id string) bool {
 	return strings.HasPrefix(strings.ToLower(id), "cve-")
 }
 
-func HasSeverityAtOrAbove(store vulnerability.MetadataProvider, severity vulnerability.Severity, matches match.Matches) bool {
+func HasSeverityAtOrAbove(store v5.VulnerabilityMetadataProvider, severity vulnerability.Severity, matches match.Matches) bool {
 	if severity == vulnerability.UnknownSeverity {
 		return false
 	}
@@ -453,7 +469,7 @@ func logListSummary(vl *monitorWriter) {
 	}
 }
 
-func updateVulnerabilityList(mon *monitorWriter, matches []match.Match, ignores []match.IgnoredMatch, dropped []match.IgnoredMatch, metadataProvider vulnerability.MetadataProvider) {
+func updateVulnerabilityList(mon *monitorWriter, matches []match.Match, ignores []match.IgnoredMatch, dropped []match.IgnoredMatch, metadataProvider v5.VulnerabilityMetadataProvider) {
 	for _, m := range matches {
 		metadata, err := metadataProvider.GetMetadata(m.Vulnerability.ID, m.Vulnerability.Namespace)
 		if err != nil || metadata == nil {
@@ -468,7 +484,7 @@ func updateVulnerabilityList(mon *monitorWriter, matches []match.Match, ignores
 		}
 		sevManualProgress.Increment()
 
-		if m.Vulnerability.Fix.State == grypeDb.FixedState {
+		if m.Vulnerability.Fix.State == vulnerability.FixStateFixed {
 			mon.Fixed.Increment()
 		}
 	}
