@@ -8,40 +8,44 @@ import (
 	"github.com/google/uuid"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
+	"github.com/wagoodman/go-partybus"
 
-	"github.com/anchore/grype/grype/db"
-	grypeDB "github.com/anchore/grype/grype/db/v5"
+	v5 "github.com/anchore/grype/grype/db/v5"
+	"github.com/anchore/grype/grype/db/v5/matcher"
+	"github.com/anchore/grype/grype/db/v5/matcher/ruby"
+	"github.com/anchore/grype/grype/db/v5/search"
 	"github.com/anchore/grype/grype/distro"
+	"github.com/anchore/grype/grype/event"
+	"github.com/anchore/grype/grype/event/monitor"
 	"github.com/anchore/grype/grype/grypeerr"
 	"github.com/anchore/grype/grype/match"
-	"github.com/anchore/grype/grype/matcher"
-	"github.com/anchore/grype/grype/matcher/ruby"
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/pkg/qualifier"
-	"github.com/anchore/grype/grype/search"
-	"github.com/anchore/grype/grype/store"
 	"github.com/anchore/grype/grype/version"
+	"github.com/anchore/grype/grype/vex"
 	"github.com/anchore/grype/grype/vulnerability"
+	"github.com/anchore/grype/internal/bus"
 	"github.com/anchore/syft/syft/cpe"
 	"github.com/anchore/syft/syft/file"
 	"github.com/anchore/syft/syft/linux"
 	syftPkg "github.com/anchore/syft/syft/pkg"
+	"github.com/anchore/syft/syft/source"
 )
 
 type ack interface {
-	grypeDB.VulnerabilityStoreReader
-	grypeDB.VulnerabilityMetadataStoreReader
-	grypeDB.VulnerabilityMatchExclusionStoreReader
+	v5.VulnerabilityStoreReader
+	v5.VulnerabilityMetadataStoreReader
+	v5.VulnerabilityMatchExclusionStoreReader
 }
 
 var _ ack = (*mockStore)(nil)
 
 type mockStore struct {
-	vulnerabilities map[string]map[string][]grypeDB.Vulnerability
-	metadata        map[string]map[string]*grypeDB.VulnerabilityMetadata
+	vulnerabilities map[string]map[string][]v5.Vulnerability
+	metadata        map[string]map[string]*v5.VulnerabilityMetadata
 }
 
-func (d *mockStore) GetVulnerabilityMatchExclusion(id string) ([]grypeDB.VulnerabilityMatchExclusion, error) {
+func (d *mockStore) GetVulnerabilityMatchExclusion(id string) ([]v5.VulnerabilityMatchExclusion, error) {
 	// panic("implement me")
 	return nil, nil
 }
@@ -55,8 +59,8 @@ type mockStoreStubFn func(*mockStore)
 // to modify the data in the mock store, such as in preparation for tests.
 func newMockStore(stubFn mockStoreStubFn) *mockStore {
 	d := &mockStore{
-		vulnerabilities: make(map[string]map[string][]grypeDB.Vulnerability),
-		metadata:        make(map[string]map[string]*grypeDB.VulnerabilityMetadata),
+		vulnerabilities: make(map[string]map[string][]v5.Vulnerability),
+		metadata:        make(map[string]map[string]*v5.VulnerabilityMetadata),
 	}
 	if stubFn != nil {
 		stubFn(d)
@@ -64,16 +68,16 @@ func newMockStore(stubFn mockStoreStubFn) *mockStore {
 	return d
 }
 
-func (d *mockStore) GetVulnerabilityMetadata(id, namespace string) (*grypeDB.VulnerabilityMetadata, error) {
+func (d *mockStore) GetVulnerabilityMetadata(id, namespace string) (*v5.VulnerabilityMetadata, error) {
 	return d.metadata[id][namespace], nil
 }
 
-func (d *mockStore) GetAllVulnerabilityMetadata() (*[]grypeDB.VulnerabilityMetadata, error) {
+func (d *mockStore) GetAllVulnerabilityMetadata() (*[]v5.VulnerabilityMetadata, error) {
 	panic("implement me")
 }
 
-func (d *mockStore) GetVulnerability(namespace, id string) ([]grypeDB.Vulnerability, error) {
-	var results []grypeDB.Vulnerability
+func (d *mockStore) GetVulnerability(namespace, id string) ([]v5.Vulnerability, error) {
+	var results []v5.Vulnerability
 	for _, vulns := range d.vulnerabilities[namespace] {
 		for _, vuln := range vulns {
 			if vuln.ID == id {
@@ -84,11 +88,11 @@ func (d *mockStore) GetVulnerability(namespace, id string) ([]grypeDB.Vulnerabil
 	return results, nil
 }
 
-func (d *mockStore) SearchForVulnerabilities(namespace, name string) ([]grypeDB.Vulnerability, error) {
+func (d *mockStore) SearchForVulnerabilities(namespace, name string) ([]v5.Vulnerability, error) {
 	return d.vulnerabilities[namespace][name], nil
 }
 
-func (d *mockStore) GetAllVulnerabilities() (*[]grypeDB.Vulnerability, error) {
+func (d *mockStore) GetAllVulnerabilities() (*[]v5.Vulnerability, error) {
 	panic("implement me")
 }
 
@@ -103,7 +107,7 @@ func (d *mockStore) GetVulnerabilityNamespaces() ([]string, error) {
 
 func defaultStubFn(d *mockStore) {
 	// METADATA /////////////////////////////////////////////////////////////////////////////////
-	d.metadata["CVE-2014-fake-1"] = map[string]*grypeDB.VulnerabilityMetadata{
+	d.metadata["CVE-2014-fake-1"] = map[string]*v5.VulnerabilityMetadata{
 		"debian:distro:debian:8": {
 			ID:        "CVE-2014-fake-1",
 			Namespace: "debian:distro:debian:8",
@@ -111,7 +115,7 @@ func defaultStubFn(d *mockStore) {
 		},
 	}
 
-	d.metadata["GHSA-2014-fake-3"] = map[string]*grypeDB.VulnerabilityMetadata{
+	d.metadata["GHSA-2014-fake-3"] = map[string]*v5.VulnerabilityMetadata{
 		"github:language:ruby": {
 			ID:        "GHSA-2014-fake-3",
 			Namespace: "github:language:ruby",
@@ -119,7 +123,7 @@ func defaultStubFn(d *mockStore) {
 		},
 	}
 
-	d.metadata["CVE-2014-fake-3"] = map[string]*grypeDB.VulnerabilityMetadata{
+	d.metadata["CVE-2014-fake-3"] = map[string]*v5.VulnerabilityMetadata{
 		"nvd:cpe": {
 			ID:        "CVE-2014-fake-3",
 			Namespace: "nvd:cpe",
@@ -128,7 +132,7 @@ func defaultStubFn(d *mockStore) {
 	}
 
 	// VULNERABILITIES ///////////////////////////////////////////////////////////////////////////
-	d.vulnerabilities["debian:distro:debian:8"] = map[string][]grypeDB.Vulnerability{
+	d.vulnerabilities["debian:distro:debian:8"] = map[string][]v5.Vulnerability{
 		"neutron": {
 			{
 				PackageName:       "neutron",
@@ -146,7 +150,7 @@ func defaultStubFn(d *mockStore) {
 			},
 		},
 	}
-	d.vulnerabilities["github:language:ruby"] = map[string][]grypeDB.Vulnerability{
+	d.vulnerabilities["github:language:ruby"] = map[string][]v5.Vulnerability{
 		"activerecord": {
 			{
 				PackageName:       "activerecord",
@@ -154,7 +158,7 @@ func defaultStubFn(d *mockStore) {
 				VersionConstraint: "< 3.7.6",
 				ID:                "GHSA-2014-fake-3",
 				VersionFormat:     "unknown",
-				RelatedVulnerabilities: []grypeDB.VulnerabilityReference{
+				RelatedVulnerabilities: []v5.VulnerabilityReference{
 					{
 						ID:        "CVE-2014-fake-3",
 						Namespace: "nvd:cpe",
@@ -163,7 +167,7 @@ func defaultStubFn(d *mockStore) {
 			},
 		},
 	}
-	d.vulnerabilities["nvd:cpe"] = map[string][]grypeDB.Vulnerability{
+	d.vulnerabilities["nvd:cpe"] = map[string][]v5.Vulnerability{
 		"activerecord": {
 			{
 				PackageName:       "activerecord",
@@ -220,8 +224,10 @@ func Test_HasSeverityAtOrAbove(t *testing.T) {
 	matches := match.NewMatches()
 	matches.Add(match.Match{
 		Vulnerability: vulnerability.Vulnerability{
-			ID:        "CVE-2014-fake-1",
-			Namespace: "debian:distro:debian:8",
+			Reference: vulnerability.Reference{
+				ID:        "CVE-2014-fake-1",
+				Namespace: "debian:distro:debian:8",
+			},
 		},
 		Package: thePkg,
 		Details: match.Details{
@@ -263,7 +269,7 @@ func Test_HasSeverityAtOrAbove(t *testing.T) {
 		},
 	}
 
-	metadataProvider := db.NewVulnerabilityMetadataProvider(newMockStore(defaultStubFn))
+	metadataProvider := v5.NewVulnerabilityMetadataProvider(newMockStore(defaultStubFn))
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
@@ -287,12 +293,12 @@ func Test_HasSeverityAtOrAbove(t *testing.T) {
 
 func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 	mkStr := newMockStore(defaultStubFn)
-	vp, err := db.NewVulnerabilityProvider(mkStr)
+	vp, err := v5.NewVulnerabilityProvider(mkStr)
 	require.NoError(t, err)
-	str := store.Store{
-		Provider:          vp,
-		MetadataProvider:  db.NewVulnerabilityMetadataProvider(mkStr),
-		ExclusionProvider: db.NewMatchExclusionProvider(mkStr),
+	str := v5.ProviderStore{
+		VulnerabilityProvider:         vp,
+		VulnerabilityMetadataProvider: v5.NewVulnerabilityMetadataProvider(mkStr),
+		ExclusionProvider:             v5.NewMatchExclusionProvider(mkStr),
 	}
 
 	neutron2013Pkg := pkg.Package{
@@ -303,7 +309,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 	}
 
 	mustCPE := func(c string) cpe.CPE {
-		cp, err := cpe.New(c)
+		cp, err := cpe.New(c, "")
 		if err != nil {
 			t.Fatal(err)
 		}
@@ -322,11 +328,12 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 	}
 
 	type fields struct {
-		Store          store.Store
+		Store          v5.ProviderStore
 		Matchers       []matcher.Matcher
 		IgnoreRules    []match.IgnoreRule
 		FailSeverity   *vulnerability.Severity
 		NormalizeByCVE bool
+		VexProcessor   *vex.Processor
 	}
 	type args struct {
 		pkgs    []pkg.Package
@@ -384,9 +391,12 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 			wantMatches: match.NewMatches(
 				match.Match{
 					Vulnerability: vulnerability.Vulnerability{
-						Constraint:        version.MustGetConstraint("< 2014.1.3-6", version.DebFormat),
-						ID:                "CVE-2014-fake-1",
-						Namespace:         "debian:distro:debian:8",
+						PackageName: "neutron",
+						Constraint:  version.MustGetConstraint("< 2014.1.3-6", version.DebFormat),
+						Reference: vulnerability.Reference{
+							ID:        "CVE-2014-fake-1",
+							Namespace: "debian:distro:debian:8",
+						},
 						PackageQualifiers: []qualifier.Qualifier{},
 						CPEs:              []cpe.CPE{},
 						Advisories:        []vulnerability.Advisory{},
@@ -437,9 +447,12 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 			wantMatches: match.NewMatches(
 				match.Match{
 					Vulnerability: vulnerability.Vulnerability{
-						Constraint:        version.MustGetConstraint("< 2014.1.3-6", version.DebFormat),
-						ID:                "CVE-2014-fake-1",
-						Namespace:         "debian:distro:debian:8",
+						PackageName: "neutron",
+						Constraint:  version.MustGetConstraint("< 2014.1.3-6", version.DebFormat),
+						Reference: vulnerability.Reference{
+							ID:        "CVE-2014-fake-1",
+							Namespace: "debian:distro:debian:8",
+						},
 						PackageQualifiers: []qualifier.Qualifier{},
 						CPEs:              []cpe.CPE{},
 						Advisories:        []vulnerability.Advisory{},
@@ -466,6 +479,89 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 			wantIgnoredMatches: nil,
 			wantErr:            grypeerr.ErrAboveSeverityThreshold,
 		},
+		{
+			name: "pass on severity threshold with VEX",
+			fields: fields{
+				Store:    str,
+				Matchers: matcher.NewDefaultMatchers(matcher.Config{}),
+				FailSeverity: func() *vulnerability.Severity {
+					x := vulnerability.LowSeverity
+					return &x
+				}(),
+				VexProcessor: vex.NewProcessor(vex.ProcessorOptions{
+					Documents: []string{
+						"vex/testdata/vex-docs/openvex-debian.json",
+					},
+					IgnoreRules: []match.IgnoreRule{
+						{
+							VexStatus: "fixed",
+						},
+					},
+				}),
+			},
+			args: args{
+				pkgs: []pkg.Package{
+					neutron2013Pkg,
+				},
+				context: pkg.Context{
+					Source: &source.Description{
+						Name:    "debian",
+						Version: "2013.1.1-1",
+						Metadata: source.ImageMetadata{
+							RepoDigests: []string{
+								"debian@sha256:124c7d2707904eea7431fffe91522a01e5a861a624ee31d03372cc1d138a3126",
+							},
+						},
+					},
+					Distro: &linux.Release{
+						ID:        "debian",
+						VersionID: "8",
+					},
+				},
+			},
+			wantMatches: match.NewMatches(),
+			wantIgnoredMatches: []match.IgnoredMatch{
+				{
+					AppliedIgnoreRules: []match.IgnoreRule{
+						{
+							Namespace: "vex",
+							VexStatus: "fixed",
+						},
+					},
+					Match: match.Match{
+						Vulnerability: vulnerability.Vulnerability{
+							PackageName: "neutron",
+							Constraint:  version.MustGetConstraint("< 2014.1.3-6", version.DebFormat),
+							Reference: vulnerability.Reference{
+								ID:        "CVE-2014-fake-1",
+								Namespace: "debian:distro:debian:8",
+							},
+							PackageQualifiers: []qualifier.Qualifier{},
+							CPEs:              []cpe.CPE{},
+							Advisories:        []vulnerability.Advisory{},
+						},
+						Package: neutron2013Pkg,
+						Details: match.Details{
+							{
+								Type: match.ExactDirectMatch,
+								SearchedBy: map[string]any{
+									"distro":    map[string]string{"type": "debian", "version": "8"},
+									"namespace": "debian:distro:debian:8",
+									"package":   map[string]string{"name": "neutron", "version": "2013.1.1-1"},
+								},
+								Found: map[string]any{
+									"versionConstraint": "< 2014.1.3-6 (deb)",
+									"vulnerabilityID":   "CVE-2014-fake-1",
+								},
+								Matcher:    "dpkg-matcher",
+								Confidence: 1,
+							},
+						},
+					},
+				},
+			},
+			wantErr: nil,
+		},
 		{
 			name: "matches by exact-direct match (language)",
 			fields: fields{
@@ -485,9 +581,12 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 			wantMatches: match.NewMatches(
 				match.Match{
 					Vulnerability: vulnerability.Vulnerability{
-						Constraint: version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
-						ID:         "CVE-2014-fake-3",
-						Namespace:  "nvd:cpe",
+						PackageName: "activerecord",
+						Constraint:  version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
+						Reference: vulnerability.Reference{
+							ID:        "CVE-2014-fake-3",
+							Namespace: "nvd:cpe",
+						},
 						CPEs: []cpe.CPE{
 							mustCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"),
 						},
@@ -501,7 +600,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 							SearchedBy: search.CPEParameters{
 								Namespace: "nvd:cpe",
 								CPEs: []string{
-									"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*",
+									"cpe:2.3:*:activerecord:activerecord:3.7.5:*:*:*:*:rails:*:*",
 								},
 								Package: search.CPEPackageParameter{
 									Name:    "activerecord",
@@ -522,9 +621,12 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 				},
 				match.Match{
 					Vulnerability: vulnerability.Vulnerability{
-						Constraint: version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
-						ID:         "GHSA-2014-fake-3",
-						Namespace:  "github:language:ruby",
+						PackageName: "activerecord",
+						Constraint:  version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
+						Reference: vulnerability.Reference{
+							ID:        "GHSA-2014-fake-3",
+							Namespace: "github:language:ruby",
+						},
 						RelatedVulnerabilities: []vulnerability.Reference{
 							{
 								ID:        "CVE-2014-fake-3",
@@ -579,9 +681,12 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 			wantMatches: match.NewMatches(
 				match.Match{
 					Vulnerability: vulnerability.Vulnerability{
-						Constraint: version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
-						ID:         "CVE-2014-fake-3",
-						Namespace:  "nvd:cpe",
+						PackageName: "activerecord",
+						Constraint:  version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
+						Reference: vulnerability.Reference{
+							ID:        "CVE-2014-fake-3",
+							Namespace: "nvd:cpe",
+						},
 						CPEs: []cpe.CPE{
 							mustCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"),
 						},
@@ -615,7 +720,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 							SearchedBy: search.CPEParameters{
 								Namespace: "nvd:cpe",
 								CPEs: []string{
-									"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*",
+									"cpe:2.3:*:activerecord:activerecord:3.7.5:*:*:*:*:rails:*:*",
 								},
 								Package: search.CPEPackageParameter{
 									Name:    "activerecord",
@@ -665,9 +770,12 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 			wantMatches: match.NewMatches(
 				match.Match{
 					Vulnerability: vulnerability.Vulnerability{
-						Constraint: version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
-						ID:         "CVE-2014-fake-3",
-						Namespace:  "nvd:cpe",
+						PackageName: "activerecord",
+						Constraint:  version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
+						Reference: vulnerability.Reference{
+							ID:        "CVE-2014-fake-3",
+							Namespace: "nvd:cpe",
+						},
 						CPEs: []cpe.CPE{
 							mustCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"),
 						},
@@ -681,7 +789,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 							SearchedBy: search.CPEParameters{
 								Namespace: "nvd:cpe",
 								CPEs: []string{
-									"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*",
+									"cpe:2.3:*:activerecord:activerecord:3.7.5:*:*:*:*:rails:*:*",
 								},
 								Package: search.CPEPackageParameter{
 									Name:    "activerecord",
@@ -702,6 +810,51 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 				},
 			),
 			wantErr: nil,
+			wantIgnoredMatches: []match.IgnoredMatch{
+				{
+					Match: match.Match{
+						Vulnerability: vulnerability.Vulnerability{
+							PackageName: "activerecord",
+							Constraint:  version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
+							Reference: vulnerability.Reference{
+								ID:        "CVE-2014-fake-3",
+								Namespace: "nvd:cpe",
+							},
+							CPEs:              []cpe.CPE{},
+							PackageQualifiers: []qualifier.Qualifier{},
+							Advisories:        []vulnerability.Advisory{},
+							RelatedVulnerabilities: []vulnerability.Reference{
+								{
+									ID:        "GHSA-2014-fake-3",
+									Namespace: "github:language:ruby",
+								},
+							},
+						},
+						Package: activerecordPkg,
+						Details: match.Details{
+							{
+								Type: match.ExactDirectMatch,
+								SearchedBy: map[string]any{
+									"language":  "ruby",
+									"namespace": "github:language:ruby",
+									"package":   map[string]string{"name": "activerecord", "version": "3.7.5"},
+								},
+								Found: map[string]any{
+									"versionConstraint": "< 3.7.6 (unknown)",
+									"vulnerabilityID":   "GHSA-2014-fake-3",
+								},
+								Matcher:    "ruby-gem-matcher",
+								Confidence: 1,
+							},
+						},
+					},
+					AppliedIgnoreRules: []match.IgnoreRule{
+						{
+							Vulnerability: "GHSA-2014-fake-3",
+						},
+					},
+				},
+			},
 		},
 		{
 			name: "normalize by cve -- ignore CVE",
@@ -729,6 +882,54 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 			},
 			wantMatches: match.NewMatches(),
 			wantIgnoredMatches: []match.IgnoredMatch{
+				{
+					Match: match.Match{
+						Vulnerability: vulnerability.Vulnerability{
+							PackageName: "activerecord",
+							Constraint:  version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
+							Reference: vulnerability.Reference{
+								ID:        "CVE-2014-fake-3",
+								Namespace: "nvd:cpe",
+							},
+							CPEs: []cpe.CPE{
+								mustCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"),
+							},
+							PackageQualifiers:      []qualifier.Qualifier{},
+							Advisories:             []vulnerability.Advisory{},
+							RelatedVulnerabilities: nil,
+						},
+						Package: activerecordPkg,
+						Details: match.Details{
+							{
+								Type: match.CPEMatch,
+								SearchedBy: search.CPEParameters{
+									Namespace: "nvd:cpe",
+									CPEs: []string{
+										"cpe:2.3:*:activerecord:activerecord:3.7.5:*:*:*:*:rails:*:*",
+									},
+									Package: search.CPEPackageParameter{
+										Name:    "activerecord",
+										Version: "3.7.5",
+									},
+								},
+								Found: search.CPEResult{
+									VulnerabilityID:   "CVE-2014-fake-3",
+									VersionConstraint: "< 3.7.6 (unknown)",
+									CPEs: []string{
+										"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*",
+									},
+								},
+								Matcher:    "ruby-gem-matcher",
+								Confidence: 0.9,
+							},
+						},
+					},
+					AppliedIgnoreRules: []match.IgnoreRule{
+						{
+							Vulnerability: "CVE-2014-fake-3",
+						},
+					},
+				},
 				{
 					AppliedIgnoreRules: []match.IgnoreRule{
 						{
@@ -737,9 +938,12 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 					},
 					Match: match.Match{
 						Vulnerability: vulnerability.Vulnerability{
-							Constraint:        version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
-							ID:                "CVE-2014-fake-3",
-							Namespace:         "nvd:cpe",
+							PackageName: "activerecord",
+							Constraint:  version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
+							Reference: vulnerability.Reference{
+								ID:        "CVE-2014-fake-3",
+								Namespace: "nvd:cpe",
+							},
 							CPEs:              []cpe.CPE{},
 							PackageQualifiers: []qualifier.Qualifier{},
 							Advisories:        []vulnerability.Advisory{},
@@ -795,9 +999,12 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 			wantMatches: match.NewMatches(
 				match.Match{
 					Vulnerability: vulnerability.Vulnerability{
-						Constraint: version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
-						ID:         "GHSA-2014-fake-3",
-						Namespace:  "github:language:ruby",
+						PackageName: "activerecord",
+						Constraint:  version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
+						Reference: vulnerability.Reference{
+							ID:        "GHSA-2014-fake-3",
+							Namespace: "github:language:ruby",
+						},
 						RelatedVulnerabilities: []vulnerability.Reference{
 							{
 								ID:        "CVE-2014-fake-3",
@@ -836,9 +1043,12 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 					},
 					Match: match.Match{
 						Vulnerability: vulnerability.Vulnerability{
-							Constraint: version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
-							ID:         "CVE-2014-fake-3",
-							Namespace:  "nvd:cpe",
+							PackageName: "activerecord",
+							Constraint:  version.MustGetConstraint("< 3.7.6", version.UnknownFormat),
+							Reference: vulnerability.Reference{
+								ID:        "CVE-2014-fake-3",
+								Namespace: "nvd:cpe",
+							},
 							CPEs: []cpe.CPE{
 								mustCPE("cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*"),
 							},
@@ -852,7 +1062,7 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 								SearchedBy: search.CPEParameters{
 									Namespace: "nvd:cpe",
 									CPEs: []string{
-										"cpe:2.3:*:activerecord:activerecord:*:*:*:*:*:rails:*:*",
+										"cpe:2.3:*:activerecord:activerecord:3.7.5:*:*:*:*:rails:*:*",
 									},
 									Package: search.CPEPackageParameter{
 										Name:    "activerecord",
@@ -884,7 +1094,13 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 				IgnoreRules:    tt.fields.IgnoreRules,
 				FailSeverity:   tt.fields.FailSeverity,
 				NormalizeByCVE: tt.fields.NormalizeByCVE,
+				VexProcessor:   tt.fields.VexProcessor,
 			}
+
+			listener := &busListener{}
+			bus.Set(listener)
+			defer bus.Set(nil)
+
 			actualMatches, actualIgnoreMatches, err := m.FindMatches(tt.args.pkgs, tt.args.context)
 			if tt.wantErr != nil {
 				require.ErrorIs(t, err, tt.wantErr)
@@ -908,6 +1124,9 @@ func TestVulnerabilityMatcher_FindMatches(t *testing.T) {
 			if d := cmp.Diff(tt.wantIgnoredMatches, actualIgnoreMatches, opts...); d != "" {
 				t.Errorf("FindMatches() ignored matches mismatch [ha!] (-want +got):\n%s", d)
 			}
+
+			// validate the bus-reported ignored counts are accurate
+			require.Equal(t, int64(len(tt.wantIgnoredMatches)), listener.matching.Ignored.Current())
 		})
 	}
 }
@@ -935,7 +1154,7 @@ func Test_indexFalsePositivesByLocation(t *testing.T) {
 				},
 			},
 			stubFunc: func(d *mockStore) {
-				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]grypeDB.Vulnerability{
+				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]v5.Vulnerability{
 					"foo": {
 						{
 							ID:                "GHSA-2014-fake-3",
@@ -971,7 +1190,7 @@ func Test_indexFalsePositivesByLocation(t *testing.T) {
 				},
 			},
 			stubFunc: func(d *mockStore) {
-				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]grypeDB.Vulnerability{
+				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]v5.Vulnerability{
 					"origin-foo": {
 						{
 							ID:                "GHSA-2014-fake-3",
@@ -1002,7 +1221,7 @@ func Test_indexFalsePositivesByLocation(t *testing.T) {
 				},
 			},
 			stubFunc: func(d *mockStore) {
-				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]grypeDB.Vulnerability{
+				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]v5.Vulnerability{
 					"foo": {
 						{
 							ID:                "GHSA-2014-fake-3",
@@ -1031,7 +1250,7 @@ func Test_indexFalsePositivesByLocation(t *testing.T) {
 				},
 			},
 			stubFunc: func(d *mockStore) {
-				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]grypeDB.Vulnerability{}
+				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]v5.Vulnerability{}
 			},
 			expectedResult: map[string][]string{},
 			errAssertion:   assert.NoError,
@@ -1046,7 +1265,7 @@ func Test_indexFalsePositivesByLocation(t *testing.T) {
 				},
 			},
 			stubFunc: func(d *mockStore) {
-				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]grypeDB.Vulnerability{
+				d.vulnerabilities["wolfi:distro:wolfi:rolling"] = map[string][]v5.Vulnerability{
 					"foo": {
 						{
 							ID:                "GHSA-2014-fake-3",
@@ -1073,17 +1292,17 @@ func Test_indexFalsePositivesByLocation(t *testing.T) {
 	}
 }
 
-func createMockStore(t *testing.T, fn mockStoreStubFn) store.Store {
+func createMockStore(t *testing.T, fn mockStoreStubFn) v5.ProviderStore {
 	t.Helper()
 
 	mkStr := newMockStore(fn)
-	vp, err := db.NewVulnerabilityProvider(mkStr)
+	vp, err := v5.NewVulnerabilityProvider(mkStr)
 	require.NoError(t, err)
 
-	return store.Store{
-		Provider:          vp,
-		MetadataProvider:  db.NewVulnerabilityMetadataProvider(mkStr),
-		ExclusionProvider: db.NewMatchExclusionProvider(mkStr),
+	return v5.ProviderStore{
+		VulnerabilityProvider:         vp,
+		VulnerabilityMetadataProvider: v5.NewVulnerabilityMetadataProvider(mkStr),
+		ExclusionProvider:             v5.NewMatchExclusionProvider(mkStr),
 	}
 }
 
@@ -1110,7 +1329,7 @@ func Test_filterMatchesUsingDistroFalsePositives(t *testing.T) {
 						Name:      "crane",
 						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
 					},
-					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+					Vulnerability: vulnerability.Vulnerability{Reference: vulnerability.Reference{ID: "CVE-2014-fake-3"}},
 				},
 			},
 			fpIndex: map[string][]string{
@@ -1126,7 +1345,7 @@ func Test_filterMatchesUsingDistroFalsePositives(t *testing.T) {
 						Name:      "crane",
 						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
 					},
-					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+					Vulnerability: vulnerability.Vulnerability{Reference: vulnerability.Reference{ID: "CVE-2014-fake-3"}},
 				},
 			},
 			fpIndex: map[string][]string{
@@ -1138,7 +1357,7 @@ func Test_filterMatchesUsingDistroFalsePositives(t *testing.T) {
 						Name:      "crane",
 						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
 					},
-					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+					Vulnerability: vulnerability.Vulnerability{Reference: vulnerability.Reference{ID: "CVE-2014-fake-3"}},
 				},
 			},
 		},
@@ -1150,7 +1369,7 @@ func Test_filterMatchesUsingDistroFalsePositives(t *testing.T) {
 						Name:      "crane",
 						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
 					},
-					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+					Vulnerability: vulnerability.Vulnerability{Reference: vulnerability.Reference{ID: "CVE-2014-fake-3"}},
 				},
 			},
 			fpIndex: map[string][]string{
@@ -1162,7 +1381,7 @@ func Test_filterMatchesUsingDistroFalsePositives(t *testing.T) {
 						Name:      "crane",
 						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
 					},
-					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+					Vulnerability: vulnerability.Vulnerability{Reference: vulnerability.Reference{ID: "CVE-2014-fake-3"}},
 				},
 			},
 		},
@@ -1174,7 +1393,7 @@ func Test_filterMatchesUsingDistroFalsePositives(t *testing.T) {
 						Name:      "crane",
 						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
 					},
-					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+					Vulnerability: vulnerability.Vulnerability{Reference: vulnerability.Reference{ID: "CVE-2014-fake-3"}},
 				},
 			},
 			fpIndex: map[string][]string{},
@@ -1184,7 +1403,7 @@ func Test_filterMatchesUsingDistroFalsePositives(t *testing.T) {
 						Name:      "crane",
 						Locations: file.NewLocationSet(file.NewLocation("/usr/bin/crane")),
 					},
-					Vulnerability: vulnerability.Vulnerability{ID: "CVE-2014-fake-3"},
+					Vulnerability: vulnerability.Vulnerability{Reference: vulnerability.Reference{ID: "CVE-2014-fake-3"}},
 				},
 			},
 		},
@@ -1197,3 +1416,17 @@ func Test_filterMatchesUsingDistroFalsePositives(t *testing.T) {
 		})
 	}
 }
+
+type busListener struct {
+	matching monitor.Matching
+}
+
+func (b *busListener) Publish(e partybus.Event) {
+	if e.Type == event.VulnerabilityScanningStarted {
+		if m, ok := e.Value.(monitor.Matching); ok {
+			b.matching = m
+		}
+	}
+}
+
+var _ partybus.Publisher = (*busListener)(nil)
