@@ -1,29 +1,38 @@
 package integration
 
 import (
+	"context"
 	"sort"
 	"strings"
 	"testing"
 
-	"github.com/facebookincubator/nvdtools/wfn"
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
 	"github.com/stretchr/testify/require"
 
 	"github.com/anchore/grype/grype"
-	"github.com/anchore/grype/grype/db"
+	v5 "github.com/anchore/grype/grype/db/v5"
+	"github.com/anchore/grype/grype/db/v5/matcher"
+	"github.com/anchore/grype/grype/db/v5/matcher/dotnet"
+	"github.com/anchore/grype/grype/db/v5/matcher/golang"
+	"github.com/anchore/grype/grype/db/v5/matcher/java"
+	"github.com/anchore/grype/grype/db/v5/matcher/javascript"
+	"github.com/anchore/grype/grype/db/v5/matcher/python"
+	"github.com/anchore/grype/grype/db/v5/matcher/ruby"
+	"github.com/anchore/grype/grype/db/v5/matcher/rust"
+	"github.com/anchore/grype/grype/db/v5/matcher/stock"
+	"github.com/anchore/grype/grype/db/v5/search"
 	"github.com/anchore/grype/grype/match"
-	"github.com/anchore/grype/grype/matcher"
 	"github.com/anchore/grype/grype/pkg"
-	"github.com/anchore/grype/grype/store"
 	"github.com/anchore/grype/grype/vex"
 	"github.com/anchore/grype/grype/vulnerability"
 	"github.com/anchore/grype/internal/stringutil"
 	"github.com/anchore/stereoscope/pkg/imagetest"
 	"github.com/anchore/syft/syft"
+	"github.com/anchore/syft/syft/cataloging/pkgcataloging"
+	"github.com/anchore/syft/syft/cpe"
 	"github.com/anchore/syft/syft/linux"
 	syftPkg "github.com/anchore/syft/syft/pkg"
-	"github.com/anchore/syft/syft/pkg/cataloger"
 	"github.com/anchore/syft/syft/source"
 )
 
@@ -35,7 +44,7 @@ func addAlpineMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Co
 	}
 	thePkg := pkg.New(packages[0])
 	theVuln := theStore.backend["alpine:distro:alpine:3.12"][thePkg.Name][0]
-	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	vulnObj, err := v5.NewVulnerability(theVuln)
 	require.NoError(t, err)
 
 	theResult.Add(match.Match{
@@ -44,6 +53,26 @@ func addAlpineMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Co
 		Vulnerability: *vulnObj,
 		Package:       thePkg,
 		Details: []match.Detail{
+			{
+				Type:       match.ExactDirectMatch,
+				Confidence: 1.0,
+				SearchedBy: map[string]any{
+					"distro": map[string]string{
+						"type":    "alpine",
+						"version": "3.12.0",
+					},
+					"namespace": "alpine:distro:alpine:3.12",
+					"package": map[string]string{
+						"name":    "libvncserver",
+						"version": "0.9.9",
+					},
+				},
+				Found: map[string]any{
+					"versionConstraint": "< 0.9.10 (unknown)",
+					"vulnerabilityID":   vulnObj.ID,
+				},
+				Matcher: match.ApkMatcher,
+			},
 			{
 				// note: the input pURL has an upstream reference (redundant)
 				Type: "exact-indirect-match",
@@ -65,26 +94,6 @@ func addAlpineMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Co
 				Matcher:    "apk-matcher",
 				Confidence: 1,
 			},
-			{
-				Type:       match.ExactDirectMatch,
-				Confidence: 1.0,
-				SearchedBy: map[string]interface{}{
-					"distro": map[string]string{
-						"type":    "alpine",
-						"version": "3.12.0",
-					},
-					"namespace": "alpine:distro:alpine:3.12",
-					"package": map[string]string{
-						"name":    "libvncserver",
-						"version": "0.9.9",
-					},
-				},
-				Found: map[string]interface{}{
-					"versionConstraint": "< 0.9.10 (unknown)",
-					"vulnerabilityID":   vulnObj.ID,
-				},
-				Matcher: match.ApkMatcher,
-			},
 		},
 	})
 }
@@ -97,7 +106,7 @@ func addJavascriptMatches(t *testing.T, theSource source.Source, catalog *syftPk
 	}
 	thePkg := pkg.New(packages[0])
 	theVuln := theStore.backend["github:language:javascript"][thePkg.Name][0]
-	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	vulnObj, err := v5.NewVulnerability(theVuln)
 	require.NoError(t, err)
 
 	theResult.Add(match.Match{
@@ -107,7 +116,7 @@ func addJavascriptMatches(t *testing.T, theSource source.Source, catalog *syftPk
 			{
 				Type:       match.ExactDirectMatch,
 				Confidence: 1.0,
-				SearchedBy: map[string]interface{}{
+				SearchedBy: map[string]any{
 					"language":  "javascript",
 					"namespace": "github:language:javascript",
 					"package": map[string]string{
@@ -115,7 +124,7 @@ func addJavascriptMatches(t *testing.T, theSource source.Source, catalog *syftPk
 						"version": thePkg.Version,
 					},
 				},
-				Found: map[string]interface{}{
+				Found: map[string]any{
 					"versionConstraint": "> 5, < 7.2.1 (unknown)",
 					"vulnerabilityID":   vulnObj.ID,
 				},
@@ -137,18 +146,17 @@ func addPythonMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Co
 	thePkg := pkg.New(packages[0])
 	normalizedName := theStore.normalizedPackageNames["github:language:python"][thePkg.Name]
 	theVuln := theStore.backend["github:language:python"][normalizedName][0]
-	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	vulnObj, err := v5.NewVulnerability(theVuln)
 	require.NoError(t, err)
 
 	theResult.Add(match.Match{
-
 		Vulnerability: *vulnObj,
 		Package:       thePkg,
 		Details: []match.Detail{
 			{
 				Type:       match.ExactDirectMatch,
 				Confidence: 1.0,
-				SearchedBy: map[string]interface{}{
+				SearchedBy: map[string]any{
 					"language":  "python",
 					"namespace": "github:language:python",
 					"package": map[string]string{
@@ -156,7 +164,7 @@ func addPythonMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Co
 						"version": thePkg.Version,
 					},
 				},
-				Found: map[string]interface{}{
+				Found: map[string]any{
 					"versionConstraint": "< 2.6.2 (python)",
 					"vulnerabilityID":   vulnObj.ID,
 				},
@@ -178,18 +186,17 @@ func addDotnetMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Co
 	thePkg := pkg.New(packages[1])
 	normalizedName := theStore.normalizedPackageNames["github:language:dotnet"][thePkg.Name]
 	theVuln := theStore.backend["github:language:dotnet"][normalizedName][0]
-	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	vulnObj, err := v5.NewVulnerability(theVuln)
 	require.NoError(t, err)
 
 	theResult.Add(match.Match{
-
 		Vulnerability: *vulnObj,
 		Package:       thePkg,
 		Details: []match.Detail{
 			{
 				Type:       match.ExactDirectMatch,
 				Confidence: 1.0,
-				SearchedBy: map[string]interface{}{
+				SearchedBy: map[string]any{
 					"language":  "dotnet",
 					"namespace": "github:language:dotnet",
 					"package": map[string]string{
@@ -197,7 +204,7 @@ func addDotnetMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Co
 						"version": thePkg.Version,
 					},
 				},
-				Found: map[string]interface{}{
+				Found: map[string]any{
 					"versionConstraint": ">= 3.7.0.0, < 3.7.12.0 (unknown)",
 					"vulnerabilityID":   vulnObj.ID,
 				},
@@ -215,18 +222,17 @@ func addRubyMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 	}
 	thePkg := pkg.New(packages[0])
 	theVuln := theStore.backend["github:language:ruby"][thePkg.Name][0]
-	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	vulnObj, err := v5.NewVulnerability(theVuln)
 	require.NoError(t, err)
 
 	theResult.Add(match.Match{
-
 		Vulnerability: *vulnObj,
 		Package:       thePkg,
 		Details: []match.Detail{
 			{
 				Type:       match.ExactDirectMatch,
 				Confidence: 1.0,
-				SearchedBy: map[string]interface{}{
+				SearchedBy: map[string]any{
 					"language":  "ruby",
 					"namespace": "github:language:ruby",
 					"package": map[string]string{
@@ -234,7 +240,7 @@ func addRubyMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 						"version": thePkg.Version,
 					},
 				},
-				Found: map[string]interface{}{
+				Found: map[string]any{
 					"versionConstraint": "> 2.0.0, <= 2.1.4 (unknown)",
 					"vulnerabilityID":   vulnObj.ID,
 				},
@@ -274,7 +280,7 @@ func addGolangMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Co
 
 		thePkg := pkg.New(p)
 		theVuln := theStore.backend["github:language:go"][thePkg.Name][0]
-		vulnObj, err := vulnerability.NewVulnerability(theVuln)
+		vulnObj, err := v5.NewVulnerability(theVuln)
 		require.NoError(t, err)
 
 		theResult.Add(match.Match{
@@ -284,7 +290,7 @@ func addGolangMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Co
 				{
 					Type:       match.ExactDirectMatch,
 					Confidence: 1.0,
-					SearchedBy: map[string]interface{}{
+					SearchedBy: map[string]any{
 						"language":  "go",
 						"namespace": "github:language:go",
 						"package": map[string]string{
@@ -292,7 +298,7 @@ func addGolangMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Co
 							"version": thePkg.Version,
 						},
 					},
-					Found: map[string]interface{}{
+					Found: map[string]any{
 						"versionConstraint": "< 1.4.0 (unknown)",
 						"vulnerabilityID":   vulnObj.ID,
 					},
@@ -321,7 +327,7 @@ func addJavaMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 	thePkg := pkg.New(theSyftPkg)
 
 	theVuln := theStore.backend["github:language:java"][lookup][0]
-	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	vulnObj, err := v5.NewVulnerability(theVuln)
 	require.NoError(t, err)
 
 	theResult.Add(match.Match{
@@ -331,7 +337,7 @@ func addJavaMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 			{
 				Type:       match.ExactDirectMatch,
 				Confidence: 1.0,
-				SearchedBy: map[string]interface{}{
+				SearchedBy: map[string]any{
 					"language":  "java",
 					"namespace": "github:language:java",
 					"package": map[string]string{
@@ -339,7 +345,7 @@ func addJavaMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 						"version": thePkg.Version,
 					},
 				},
-				Found: map[string]interface{}{
+				Found: map[string]any{
 					"versionConstraint": ">= 0.0.1, < 1.2.0 (unknown)",
 					"vulnerabilityID":   vulnObj.ID,
 				},
@@ -358,18 +364,17 @@ func addDpkgMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 	thePkg := pkg.New(packages[0])
 	// NOTE: this is an indirect match, in typical debian style
 	theVuln := theStore.backend["debian:distro:debian:8"][thePkg.Name+"-dev"][0]
-	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	vulnObj, err := v5.NewVulnerability(theVuln)
 	require.NoError(t, err)
 
 	theResult.Add(match.Match{
-
 		Vulnerability: *vulnObj,
 		Package:       thePkg,
 		Details: []match.Detail{
 			{
 				Type:       match.ExactIndirectMatch,
 				Confidence: 1.0,
-				SearchedBy: map[string]interface{}{
+				SearchedBy: map[string]any{
 					"distro": map[string]string{
 						"type":    "debian",
 						"version": "8",
@@ -380,7 +385,7 @@ func addDpkgMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 						"version": "1.8.2",
 					},
 				},
-				Found: map[string]interface{}{
+				Found: map[string]any{
 					"versionConstraint": "<= 1.8.2 (deb)",
 					"vulnerabilityID":   vulnObj.ID,
 				},
@@ -398,7 +403,7 @@ func addPortageMatches(t *testing.T, theSource source.Source, catalog *syftPkg.C
 	}
 	thePkg := pkg.New(packages[0])
 	theVuln := theStore.backend["gentoo:distro:gentoo:2.8"][thePkg.Name][0]
-	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	vulnObj, err := v5.NewVulnerability(theVuln)
 	require.NoError(t, err)
 
 	theResult.Add(match.Match{
@@ -408,7 +413,7 @@ func addPortageMatches(t *testing.T, theSource source.Source, catalog *syftPkg.C
 			{
 				Type:       match.ExactDirectMatch,
 				Confidence: 1.0,
-				SearchedBy: map[string]interface{}{
+				SearchedBy: map[string]any{
 					"distro": map[string]string{
 						"type":    "gentoo",
 						"version": "2.8",
@@ -419,7 +424,7 @@ func addPortageMatches(t *testing.T, theSource source.Source, catalog *syftPkg.C
 						"version": "1.5.1",
 					},
 				},
-				Found: map[string]interface{}{
+				Found: map[string]any{
 					"versionConstraint": "< 1.6.0 (unknown)",
 					"vulnerabilityID":   vulnObj.ID,
 				},
@@ -437,18 +442,17 @@ func addRhelMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 	}
 	thePkg := pkg.New(packages[0])
 	theVuln := theStore.backend["redhat:distro:redhat:8"][thePkg.Name][0]
-	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	vulnObj, err := v5.NewVulnerability(theVuln)
 	require.NoError(t, err)
 
 	theResult.Add(match.Match{
-
 		Vulnerability: *vulnObj,
 		Package:       thePkg,
 		Details: []match.Detail{
 			{
 				Type:       match.ExactDirectMatch,
 				Confidence: 1.0,
-				SearchedBy: map[string]interface{}{
+				SearchedBy: map[string]any{
 					"distro": map[string]string{
 						"type":    "centos",
 						"version": "8",
@@ -459,7 +463,7 @@ func addRhelMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 						"version": "0:0.9.2-1",
 					},
 				},
-				Found: map[string]interface{}{
+				Found: map[string]any{
 					"versionConstraint": "<= 1.0.42 (rpm)",
 					"vulnerabilityID":   vulnObj.ID,
 				},
@@ -477,7 +481,7 @@ func addSlesMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 	}
 	thePkg := pkg.New(packages[0])
 	theVuln := theStore.backend["redhat:distro:redhat:8"][thePkg.Name][0]
-	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	vulnObj, err := v5.NewVulnerability(theVuln)
 	require.NoError(t, err)
 
 	vulnObj.Namespace = "sles:distro:sles:12.5"
@@ -488,7 +492,7 @@ func addSlesMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 			{
 				Type:       match.ExactDirectMatch,
 				Confidence: 1.0,
-				SearchedBy: map[string]interface{}{
+				SearchedBy: map[string]any{
 					"distro": map[string]string{
 						"type":    "sles",
 						"version": "12.5",
@@ -499,7 +503,7 @@ func addSlesMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 						"version": "0:0.9.2-1",
 					},
 				},
-				Found: map[string]interface{}{
+				Found: map[string]any{
 					"versionConstraint": "<= 1.0.42 (rpm)",
 					"vulnerabilityID":   vulnObj.ID,
 				},
@@ -517,7 +521,7 @@ func addHaskellMatches(t *testing.T, theSource source.Source, catalog *syftPkg.C
 	}
 	thePkg := pkg.New(packages[0])
 	theVuln := theStore.backend["github:language:haskell"][strings.ToLower(thePkg.Name)][0]
-	vulnObj, err := vulnerability.NewVulnerability(theVuln)
+	vulnObj, err := v5.NewVulnerability(theVuln)
 	require.NoError(t, err)
 
 	theResult.Add(match.Match{
@@ -545,6 +549,50 @@ func addHaskellMatches(t *testing.T, theSource source.Source, catalog *syftPkg.C
 	})
 }
 
+func addJvmMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Collection, theStore *mockStore, theResult *match.Matches) {
+	packages := catalog.PackagesByPath("/opt/java/openjdk/release")
+	if len(packages) < 1 {
+		t.Logf("JVM Packages: %+v", packages)
+		t.Fatalf("problem with upstream syft cataloger (java-jvm-cataloger)")
+	}
+
+	for _, p := range packages {
+		thePkg := pkg.New(p)
+		theVuln := theStore.backend["nvd:cpe"][strings.ToLower(thePkg.Name)][0]
+		vulnObj, err := v5.NewVulnerability(theVuln)
+		vulnObj.CPEs = []cpe.CPE{
+			cpe.Must("cpe:2.3:a:oracle:jdk:*:*:*:*:*:*:*:*", ""),
+		}
+		require.NoError(t, err)
+
+		theResult.Add(match.Match{
+			Vulnerability: *vulnObj,
+			Package:       thePkg,
+			Details: []match.Detail{
+				{
+					Type:       match.CPEMatch,
+					Confidence: 0.9,
+					SearchedBy: search.CPEParameters{
+						Namespace: "nvd:cpe",
+						CPEs: []string{
+							"cpe:2.3:a:oracle:jdk:1.8.0:update400:*:*:*:*:*:*",
+						},
+						Package: search.CPEPackageParameter{Name: "jdk", Version: "1.8.0_400-b07"},
+					},
+					Found: search.CPEResult{
+						VulnerabilityID:   "CVE-jdk",
+						VersionConstraint: "< 1.8.0_401 (jvm)",
+						CPEs: []string{
+							"cpe:2.3:a:oracle:jdk:*:*:*:*:*:*:*:*",
+						},
+					},
+					Matcher: match.StockMatcher,
+				},
+			},
+		})
+	}
+}
+
 func addRustMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Collection, theStore *mockStore, theResult *match.Matches) {
 	packages := catalog.PackagesByPath("/hello-auditable")
 	if len(packages) < 1 {
@@ -555,7 +603,7 @@ func addRustMatches(t *testing.T, theSource source.Source, catalog *syftPkg.Coll
 	for _, p := range packages {
 		thePkg := pkg.New(p)
 		theVuln := theStore.backend["github:language:rust"][strings.ToLower(thePkg.Name)][0]
-		vulnObj, err := vulnerability.NewVulnerability(theVuln)
+		vulnObj, err := v5.NewVulnerability(theVuln)
 		require.NoError(t, err)
 
 		theResult.Add(match.Match{
@@ -592,11 +640,11 @@ func TestMatchByImage(t *testing.T) {
 	}
 
 	tests := []struct {
-		fixtureImage string
-		expectedFn   func(source.Source, *syftPkg.Collection, *mockStore) match.Matches
+		name       string
+		expectedFn func(source.Source, *syftPkg.Collection, *mockStore) match.Matches
 	}{
 		{
-			fixtureImage: "image-debian-match-coverage",
+			name: "image-debian-match-coverage",
 			expectedFn: func(theSource source.Source, catalog *syftPkg.Collection, theStore *mockStore) match.Matches {
 				expectedMatches := match.NewMatches()
 				addPythonMatches(t, theSource, catalog, theStore, &expectedMatches)
@@ -611,7 +659,7 @@ func TestMatchByImage(t *testing.T) {
 			},
 		},
 		{
-			fixtureImage: "image-centos-match-coverage",
+			name: "image-centos-match-coverage",
 			expectedFn: func(theSource source.Source, catalog *syftPkg.Collection, theStore *mockStore) match.Matches {
 				expectedMatches := match.NewMatches()
 				addRhelMatches(t, theSource, catalog, theStore, &expectedMatches)
@@ -619,7 +667,7 @@ func TestMatchByImage(t *testing.T) {
 			},
 		},
 		{
-			fixtureImage: "image-alpine-match-coverage",
+			name: "image-alpine-match-coverage",
 			expectedFn: func(theSource source.Source, catalog *syftPkg.Collection, theStore *mockStore) match.Matches {
 				expectedMatches := match.NewMatches()
 				addAlpineMatches(t, theSource, catalog, theStore, &expectedMatches)
@@ -627,73 +675,102 @@ func TestMatchByImage(t *testing.T) {
 			},
 		},
 		{
-			fixtureImage: "image-sles-match-coverage",
+			name: "image-sles-match-coverage",
 			expectedFn: func(theSource source.Source, catalog *syftPkg.Collection, theStore *mockStore) match.Matches {
 				expectedMatches := match.NewMatches()
 				addSlesMatches(t, theSource, catalog, theStore, &expectedMatches)
 				return expectedMatches
 			},
 		},
+		// TODO: add this back in when #744 is fully implemented (see https://github.com/anchore/grype/issues/744#issuecomment-2448163737)
+		//{
+		//	name: "image-portage-match-coverage",
+		//	expectedFn: func(theSource source.Source, catalog *syftPkg.Collection, theStore *mockStore) match.Matches {
+		//		expectedMatches := match.NewMatches()
+		//		addPortageMatches(t, theSource, catalog, theStore, &expectedMatches)
+		//		return expectedMatches
+		//	},
+		//},
 		{
-			fixtureImage: "image-portage-match-coverage",
-			expectedFn: func(theSource source.Source, catalog *syftPkg.Collection, theStore *mockStore) match.Matches {
-				expectedMatches := match.NewMatches()
-				addPortageMatches(t, theSource, catalog, theStore, &expectedMatches)
-				return expectedMatches
-			},
-		},
-		{
-			fixtureImage: "image-rust-auditable-match-coverage",
+			name: "image-rust-auditable-match-coverage",
 			expectedFn: func(theSource source.Source, catalog *syftPkg.Collection, theStore *mockStore) match.Matches {
 				expectedMatches := match.NewMatches()
 				addRustMatches(t, theSource, catalog, theStore, &expectedMatches)
 				return expectedMatches
 			},
 		},
+		{
+			name: "image-jvm-match-coverage",
+			expectedFn: func(theSource source.Source, catalog *syftPkg.Collection, theStore *mockStore) match.Matches {
+				expectedMatches := match.NewMatches()
+				addJvmMatches(t, theSource, catalog, theStore, &expectedMatches)
+				return expectedMatches
+			},
+		},
 	}
 
 	for _, test := range tests {
-		t.Run(test.fixtureImage, func(t *testing.T) {
+		t.Run(test.name, func(t *testing.T) {
 			theStore := newMockDbStore()
 
-			imagetest.GetFixtureImage(t, "docker-archive", test.fixtureImage)
-			tarPath := imagetest.GetFixtureImageTarPath(t, test.fixtureImage)
-
-			userImage := "docker-archive:" + tarPath
-
-			detection, err := source.Detect(userImage, source.DetectConfig{})
-			require.NoError(t, err)
+			imagetest.GetFixtureImage(t, "docker-archive", test.name)
+			tarPath := imagetest.GetFixtureImageTarPath(t, test.name)
 
 			// this is purely done to help setup mocks
-			theSource, err := detection.NewSource(source.DetectionSourceConfig{})
+			theSource, err := syft.GetSource(context.Background(), tarPath, syft.DefaultGetSourceConfig().WithSources("docker-archive"))
 			require.NoError(t, err)
 			t.Cleanup(func() {
 				require.NoError(t, theSource.Close())
 			})
 
 			// TODO: relationships are not verified at this time
-			config := cataloger.DefaultConfig()
+			// enable all catalogers to cover non default cases
+			config := syft.DefaultCreateSBOMConfig().WithCatalogerSelection(pkgcataloging.NewSelectionRequest().WithDefaults("all"))
 			config.Search.Scope = source.SquashedScope
 
-			// enable all catalogers to cover non default cases
-			config.Catalogers = []string{"all"}
-
-			collection, _, theDistro, err := syft.CatalogPackages(theSource, config)
+			s, err := syft.CreateSBOM(context.Background(), theSource, config)
 			require.NoError(t, err)
+			require.NotNil(t, s)
 
-			matchers := matcher.NewDefaultMatchers(matcher.Config{})
+			// TODO: we need to use the API default configuration, not something hard coded here
+			matchers := matcher.NewDefaultMatchers(matcher.Config{
+				Java: java.MatcherConfig{
+					UseCPEs: true,
+				},
+				Ruby: ruby.MatcherConfig{
+					UseCPEs: true,
+				},
+				Python: python.MatcherConfig{
+					UseCPEs: true,
+				},
+				Dotnet: dotnet.MatcherConfig{
+					UseCPEs: true,
+				},
+				Javascript: javascript.MatcherConfig{
+					UseCPEs: true,
+				},
+				Golang: golang.MatcherConfig{
+					UseCPEs: true,
+				},
+				Rust: rust.MatcherConfig{
+					UseCPEs: true,
+				},
+				Stock: stock.MatcherConfig{
+					UseCPEs: true,
+				},
+			})
 
-			vp, err := db.NewVulnerabilityProvider(theStore)
+			vp, err := v5.NewVulnerabilityProvider(theStore)
 			require.NoError(t, err)
-			mp := db.NewVulnerabilityMetadataProvider(theStore)
-			ep := db.NewMatchExclusionProvider(theStore)
-			str := store.Store{
-				Provider:          vp,
-				MetadataProvider:  mp,
-				ExclusionProvider: ep,
+			mp := v5.NewVulnerabilityMetadataProvider(theStore)
+			ep := v5.NewMatchExclusionProvider(theStore)
+			str := v5.ProviderStore{
+				VulnerabilityProvider:         vp,
+				VulnerabilityMetadataProvider: mp,
+				ExclusionProvider:             ep,
 			}
 
-			actualResults := grype.FindVulnerabilitiesForPackage(str, theDistro, matchers, pkg.FromCollection(collection, pkg.SynthesisConfig{}))
+			actualResults := grype.FindVulnerabilitiesForPackage(str, s.Artifacts.LinuxDistribution, matchers, pkg.FromCollection(s.Artifacts.Packages, pkg.SynthesisConfig{}))
 			for _, m := range actualResults.Sorted() {
 				for _, d := range m.Details {
 					observedMatchers.Add(string(d.Matcher))
@@ -701,7 +778,7 @@ func TestMatchByImage(t *testing.T) {
 			}
 
 			// build expected matches from what's discovered from the catalog
-			expectedMatches := test.expectedFn(theSource, collection, theStore)
+			expectedMatches := test.expectedFn(theSource, s.Artifacts.Packages, theStore)
 
 			assertMatches(t, expectedMatches.Sorted(), actualResults.Sorted())
 		})
@@ -754,6 +831,7 @@ func TestMatchByImage(t *testing.T) {
 	observedMatchers.Remove(string(match.StockMatcher))
 	definedMatchers.Remove(string(match.StockMatcher))
 	definedMatchers.Remove(string(match.MsrcMatcher))
+	definedMatchers.Remove(string(match.PortageMatcher)) // TODO: add this back in when #744 is complete
 
 	if len(observedMatchers) != len(definedMatchers) {
 		t.Errorf("matcher coverage incomplete (matchers=%d, coverage=%d)", len(definedMatchers), len(observedMatchers))
@@ -764,7 +842,6 @@ func TestMatchByImage(t *testing.T) {
 
 		t.Log(cmp.Diff(defs, obs))
 	}
-
 }
 
 // testIgnoredMatches returns an list of ignored matches to test the vex
@@ -774,8 +851,10 @@ func testIgnoredMatches() []match.IgnoredMatch {
 		{
 			Match: match.Match{
 				Vulnerability: vulnerability.Vulnerability{
-					ID:        "CVE-alpine-libvncserver",
-					Namespace: "alpine:distro:alpine:3.12",
+					Reference: vulnerability.Reference{
+						ID:        "CVE-alpine-libvncserver",
+						Namespace: "alpine:distro:alpine:3.12",
+					},
 				},
 				Package: pkg.Package{
 					ID:       "44fa3691ae360cac",
@@ -783,12 +862,14 @@ func testIgnoredMatches() []match.IgnoredMatch {
 					Version:  "0.9.9",
 					Licenses: []string{"GPL-2.0-or-later"},
 					Type:     "apk",
-					CPEs: []wfn.Attributes{
+					CPEs: []cpe.CPE{
 						{
-							Part:    "a",
-							Vendor:  "libvncserver",
-							Product: "libvncserver",
-							Version: "0.9.9",
+							Attributes: cpe.Attributes{
+								Part:    "a",
+								Vendor:  "libvncserver",
+								Product: "libvncserver",
+								Version: "0.9.9",
+							},
 						},
 					},
 					PURL:      "pkg:apk/alpine/libvncserver@0.9.9?arch=x86_64&distro=alpine-3.12.0",
@@ -835,7 +916,7 @@ func vexMatches(t *testing.T, ignoredMatches []match.IgnoredMatch, vexStatus vex
 
 	pctx := &pkg.Context{
 		Source: &source.Description{
-			Metadata: source.StereoscopeImageSourceMetadata{
+			Metadata: source.ImageMetadata{
 				RepoDigests: []string{
 					"alpine@sha256:ffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffff",
 				},
@@ -858,7 +939,7 @@ func vexMatches(t *testing.T, ignoredMatches []match.IgnoredMatch, vexStatus vex
 
 func assertMatches(t *testing.T, expected, actual []match.Match) {
 	t.Helper()
-	var opts = []cmp.Option{
+	opts := []cmp.Option{
 		cmpopts.IgnoreFields(vulnerability.Vulnerability{}, "Constraint"),
 		cmpopts.IgnoreFields(pkg.Package{}, "Locations"),
 		cmpopts.SortSlices(func(a, b match.Match) bool {
